Manyconfig
##########

An easy-to-use declarative loader of configuration

What does it do?
================

Manyconfig lets you describe your configuration using simple blocks. You can
then load this configuration in a simple statement, even if it is scattered
across various file and environment variables.

We call these descriptions a MetaConfig not to confuse them with the
configuration itself, which is the result of loading a MetaConfig.

I can't leverage Manyconfig for my use case!
============================================

If that's the case, please tell me. Manyconfig is still in its early days, so
this is bound to happen. I'll happily add building blocks if it enables more
use cases.
